# IOC Finder

[![PyPi](https://img.shields.io/pypi/v/ioc_finder.svg)](https://pypi.python.org/pypi/ioc_finder)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ioc-finder)
[![CI](https://github.com/fhightower/ioc-finder/workflows/CI/badge.svg)](https://github.com/fhightower/ioc-finder/actions)
[![Lint](https://github.com/fhightower/ioc-finder/workflows/Lint/badge.svg)](https://github.com/fhightower/ioc-finder/actions)
[![codecov](https://codecov.io/gh/fhightower/ioc-finder/branch/master/graph/badge.svg)](https://codecov.io/gh/fhightower/ioc-finder)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://choosealicense.com/licenses/lgpl-3.0/)
[![live demo](https://img.shields.io/badge/live%20demo-%E2%86%92-green)](https://hightower.space/ioc-finder/)

Parse [indicators of compromise](https://searchsecurity.techtarget.com/definition/Indicators-of-Compromise-IOC) (also known as "observables" or "network data" - e.g. urls, email addresses, etc) from text.

📖 [Documentation](https://hightower.space/ioc-finder) (it's interactive!)

💪 I'm looking for [sponsorship](https://github.com/sponsors/fhightower) for this project.
I have a number of improvements and helpful features I'd like to add and would appreciate some support as I invest this time and focus.
If you use this project for in a commercial capacity and/or find it useful, please consider [contributing](https://github.com/sponsors/fhightower) even a small amount. Thanks!

